<?php
/**
 * The template for adding Featured Slider Options in Customizer
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */

//Featured Slider
$wp_customize->add_section( 'parallax_frame_featured_slider', array(
	'priority'		=> 400,
	'title'			=> esc_html__( 'Featured Slider', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_option'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$featured_slider_content_options = parallax_frame_featured_slider_content_options();
$choices = array();
foreach ( $featured_slider_content_options as $featured_slider_content_option ) {
	$choices[$featured_slider_content_option['value']] = $featured_slider_content_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_option]', array(
	'choices'  => $choices,
	'label'    => esc_html__( 'Enable Slider on', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_featured_slider',
	'settings' => 'parallax_frame_theme_options[featured_slider_option]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_transition_effect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_effect'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_slider_transition_effects = parallax_frame_featured_slider_transition_effects();
$choices = array();
foreach ( $parallax_frame_featured_slider_transition_effects as $parallax_frame_featured_slider_transition_effect ) {
	$choices[$parallax_frame_featured_slider_transition_effect['value']] = $parallax_frame_featured_slider_transition_effect['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_transition_effect]' , array(
	'active_callback' => 'parallax_frame_is_slider_active',
	'choices'         => $choices,
	'label'           => esc_html__( 'Transition Effect', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[featured_slider_transition_effect]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_transition_delay]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_delay'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_transition_delay]' , array(
	'active_callback' => 'parallax_frame_is_slider_active',
	'description'     => esc_html__( 'seconds(s)', 'parallax-frame-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 40px;'
		),
	'label'           => esc_html__( 'Transition Delay', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[featured_slider_transition_delay]',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_transition_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_length'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_transition_length]' , array(
		'active_callback' => 'parallax_frame_is_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'parallax-frame-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 40px;'
		),
		'label'           => esc_html__( 'Transition Length', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_slider_transition_length]',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_image_loader]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_slider_image_loader'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$featured_slider_image_loader_options = parallax_frame_featured_slider_image_loader();
$choices = array();
foreach ( $featured_slider_image_loader_options as $featured_slider_image_loader_option ) {
	$choices[$featured_slider_image_loader_option['value']] = $featured_slider_image_loader_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_image_loader]', array(
	'active_callback' => 'parallax_frame_is_slider_active',
	'description'     => esc_html__( 'True: Fixes the height overlap issue. Slideshow will start as soon as two slider are available. Slide may display in random, as image is fetch. Wait: Fixes the height overlap issue. Slideshow will start only after all images are available.', 'parallax-frame-pro' ),
	'choices'         => $choices,
	'label'           => esc_html__( 'Image Loader', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[featured_slider_image_loader]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_type'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$featured_slider_types = parallax_frame_featured_slider_types();
$choices = array();
foreach ( $featured_slider_types as $featured_slider_type ) {
	$choices[$featured_slider_type['value']] = $featured_slider_type['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_type]', array(
	'active_callback' => 'parallax_frame_is_slider_active',
	'choices'         => $choices,
	'label'           => esc_html__( 'Select Slider Type', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[featured_slider_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_number]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_number'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_number]' , array(
	'active_callback' => 'parallax_frame_is_demo_slider_inactive',
	'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'parallax-frame-pro' ),
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 0,
		'max'  => 20,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of Slides', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[featured_slider_number]',
	'type'            => 'number',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[exclude_slider_post]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['exclude_slider_post'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control(  'parallax_frame_theme_options[exclude_slider_post]', array(
	'active_callback' => 'parallax_frame_is_post_slider_active',
	'label'           => esc_html__( 'Check to exclude Slider post from Homepage posts', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[exclude_slider_post]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_select_category]', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'parallax_frame_sanitize_category_list',
) );

$wp_customize->add_control( new parallax_frame_customize_dropdown_categories_control( $wp_customize, 'parallax_frame_featured_slider_select_category', array(
	'active_callback' => 'parallax_frame_is_category_slider_active',
	'label'           => esc_html__( 'Select Categories', 'parallax-frame-pro' ),
	'name'            => 'parallax_frame_theme_options[featured_slider_select_category]',
	'section'         => 'parallax_frame_featured_slider',
	'settings'        => 'parallax_frame_theme_options[featured_slider_select_category]',
	'type'            => 'dropdown-categories',
) ) );

//loop for featured post sliders
for ( $i=1; $i <=  $options['featured_slider_number'] ; $i++ ) {
	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_post_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_page',
	) );

	$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_post_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_post_slider_active',
		'input_attrs'     => array(
			'style' => 'width: 80px;'
		),
		'label'           => esc_html__( 'Featured Post', 'parallax-frame-pro' ) . ' # ' . $i ,
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_slider_post_'. $i .']',
		'type'            => 'text',
		)
	);

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_page_'. $i .']', array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_page',
	) );

	$wp_customize->add_control( 'parallax_frame_theme_options[featured_slider_page_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_page_slider_active',
		'label'           => esc_html__( 'Featured Page', 'parallax-frame-pro' ) . ' # ' . $i ,
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_slider_page_'. $i .']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new parallax_frame_note_control( $wp_customize, 'featured_slider_note_'. $i, array(
		'active_callback' => 'parallax_frame_is_image_slider_active',
		'label'           => esc_html__( 'Featured Slide #', 'parallax-frame-pro' ) . $i,
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_slider_note_'. $i .']',
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_slider_image_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_slider_image_'. $i , array(
		'active_callback' => 'parallax_frame_is_image_slider_active',
		'label'           => esc_html__( 'Image', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_slider_image_'. $i .']',
	) ) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[featured_link_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_image_slider_active',
		'label'           => esc_html__( 'Link', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_link_'. $i .']',
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_target_'. $i .']', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[featured_target_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_image_slider_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_target_'. $i .']',
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'parallax_frame_theme_options[featured_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[featured_title_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_image_slider_active',
		'label'           => esc_html__( 'Title', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_title_'. $i .']',
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_image_slider_active',
		'label'           => esc_html__( 'Content', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_slider',
		'settings'        => 'parallax_frame_theme_options[featured_content_'. $i .']',
		'type'            => 'textarea',
    ) );
}
// Featured Slider End